# Pick Lists

In addition to the standard Echo fields, we suggest the following:

- `Destination Sample Name`
- `Source Concentration`
- `Stage`

# Surveys

## Caveats

- Cherry Pick survey reports include the source plate name, barcode, and type for *every well*.  It is unclear whether this is needless redundancy (the library currently assumes this), or whether reports might include multiple plates in some circumstances.
